<?php

App::uses('CakeEmail', 'Network/Email');


/**
 * Business logic for user accounts
 */
class User extends AppModel {

	public $displayField = "email";

	public $order = array('email' => 'ASC');

	public $belongsTo = array(
		'UserGroup'
	);



	/**
	 * Ensure the password is encrypted if present before it's saved to the DB
	 *
	 * @param array $options beforeSave options
	 *
	 * @return void
	 */
	public function beforeSave($options = array()) {

		if (isset($this->data[$this->alias]['password']) && ! empty($this->data[$this->alias]['password'])) {

			$this->data[$this->alias]['password'] = AuthComponent::password($this->data[$this->alias]['password']);
		} else {

			unset($this->data[$this->alias]['password']);
		}
	}

	public $validate = array(
		'user_group_id' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank'
			)
		),
		'email' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank'
			),
			'email' => array(
				'rule' => 'email',
				'message' => 'must be a valid email'
			),
			'unique' => array(
				'rule' => 'isUnique',
				'message' => 'A user with that email address already exists'
			)
		),
		'password' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank',
				'on' => 'create'
			)
		),
		'confirm_password' => array(
			'required' => array(
				'rule' => 'notEmpty',
				'message' => 'cannot be blank',
				'on' => 'create'
			),
			'matches' => array(
				'rule' => array('checkMatches', 'password'),
				'message' => 'passwords do not match'
			)
		)

	);



	/**
	 * Validate password rules
	 */
	public function validatePassword() {

		return array(
			'password' => array(
				'required' => array(
					'rule' => 'notEmpty',
					'message' => 'cannot be blank'
				)
			),
			'confirm_password' => array(
				'required' => array(
					'rule' => 'notEmpty',
					'message' => 'cannot be blank'
				),
				'matches' => array(
					'rule' => array('checkMatches', 'password'),
					'message' => 'passwords do not match'
				)
			)
		);

	}


	public function validateEdit() {

		$rules = $this->validates;

		unset($rules['password']);
		unset($rules['confirm_password']);

		return $rules;

	}



	/**
	 * Validation rules for a login form submission
	 */
	public function validateLogin() {

		return array(
			'email' => array(
				'required' => array(
					'rule' => 'notEmpty',
					'message' => 'cannot be blank'
				),
				'email' => array(
					'rule' => 'email',
					'message' => 'must be a valid email'
				)
			),
			'password' => array(
				'required' => array(
					'rule' => 'notEmpty',
					'message' => 'cannot be blank'
				)
			)
		);

	}



	/**
	 * Returns true if an email already exists
	 *
	 * @param array $check email field to check
	 *
	 * @return true if email doesn't exists, otherwise false
	 */
	public function checkIsRegistered($check) {

		App::uses('User', 'Model');

		$value = array_pop($check);

		$user = $this->User->findByEmail($value);

		return empty($user);

	}

/**
 * Gets the user and all associated data out that is needed for login
 * @param  int $id  The ID of the user
 * @return array 	User array
 */
	public function getUserForLogin($id) {

		$fullUser = $this->find('first', array(
				'conditions' => array(
					$this->alias.'.id' => $id
				),
				'contain'=> array(
					'UserGroup'
				)
			)
		);

		return $fullUser; 

	}

}